only poll clifd if successfully bound
authorbodea <bodea>
Sun, 23 Apr 2006 23:18:30 +0000 (23:18 +0000)
committerbodea <bodea>
Sun, 23 Apr 2006 23:18:30 +0000 (23:18 +0000)
Changes
l2tpns.c
l2tpns.h
l2tpns.spec

diff --git a/Changes b/Changes
index 1f6bbde..36a1d11 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,3 +1,6 @@
+* Mon Apr 24 2006 Brendan O'Dea <bod@optus.net> 2.1.19
+- Only poll clifd if successfully bound.
+
 * Tue Apr 18 2006 Brendan O'Dea <bod@optus.net> 2.1.18
 - Don't shutdown on TerminateReq, wait for CDN.
 - Interpret "local" direction correctly (as LAC) in disconnect AVPs.
index 6a691ec..b181ca4 100644 (file)
--- a/l2tpns.c
+++ b/l2tpns.c
@@ -4,7 +4,7 @@
 // Copyright (c) 2002 FireBrick (Andrews & Arnold Ltd / Watchfront Ltd) - GPL licenced
 // vim: sw=8 ts=8
 
-char const *cvs_id_l2tpns = "$Id: l2tpns.c,v 1.161 2006/04/18 06:00:46 bodea Exp $";
+char const *cvs_id_l2tpns = "$Id: l2tpns.c,v 1.162 2006/04/23 23:18:31 bodea Exp $";
 
 #include <arpa/inet.h>
 #include <assert.h>
@@ -3255,9 +3255,12 @@ static void mainloop(void)
                e.events = EPOLLIN;
                i = 0;
 
-               d[i].type = FD_TYPE_CLI;
-               e.data.ptr = &d[i++];
-               epoll_ctl(epollfd, EPOLL_CTL_ADD, clifd, &e);
+               if (clifd >= 0)
+               {
+                       d[i].type = FD_TYPE_CLI;
+                       e.data.ptr = &d[i++];
+                       epoll_ctl(epollfd, EPOLL_CTL_ADD, clifd, &e);
+               }
 
                d[i].type = FD_TYPE_CLUSTER;
                e.data.ptr = &d[i++];
index 12b7440..d89f3ee 100644 (file)
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.113 2006/04/18 06:00:08 bodea Exp $
+// $Id: l2tpns.h,v 1.114 2006/04/23 23:18:32 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -14,7 +14,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION        "2.1.18"
+#define VERSION        "2.1.19"
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
index f8f3ffc..cf493ff 100644 (file)
@@ -1,6 +1,6 @@
 Summary: A high-speed clustered L2TP LNS
 Name: l2tpns
-Version: 2.1.18
+Version: 2.1.19
 Release: 1
 License: GPL
 Group: System Environment/Daemons
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
-* Tue Apr 18 2006 Brendan O'Dea <bod@optus.net> 2.1.18-1
-- 2.1.18 release, see /usr/share/doc/l2tpns-2.1.18/Changes
+* Mon Apr 24 2006 Brendan O'Dea <bod@optus.net> 2.1.19-1
+- 2.1.19 release, see /usr/share/doc/l2tpns-2.1.19/Changes